@@ -28,7 +28,6 @@ make_content <- function(type, ...) {
 }
 
 
-
 #' Get all registered options for the type-argument in the `makeme`-function
 #'
 #'
@@ -95,13 +94,17 @@ make_content <- function(type, ...) {
 #' @examples get_makeme_types()
 get_makeme_types <- function() {
   out <- as.character(utils::methods("make_content"))
-  stringi::stri_replace_first_fixed(out[out != "make_content.default"],
-    pattern = "make_content.", replacement = ""
+  stringi::stri_replace_first_fixed(
+    out[out != "make_content.default"],
+    pattern = "make_content.",
+    replacement = ""
   )
 }
 
 
 #' @export
 make_content.default <- function(type, ...) {
-  cli::cli_abort("Invalid make_content-type: {type}. Check that you have loaded the required packages/methods and registererd your custom method.")
+  cli::cli_abort(
+    "Invalid make_content-type: {type}. Check that you have loaded the required packages/methods and registererd your custom method."
+  )
 }
