@@ -33,6 +33,13 @@
 #'
 #'   One of "proportion", "percentage", "percentage_bare", "count", "mean", or "median".
 #'
+#' @param data_label_position *Data label position*
+#'
+#'   `scalar<character>` // *default:* `"center"` (`optional`)
+#'
+#'   Position of data labels on bars. One of "center" (middle of bar), "bottom" (bottom but inside bar),
+#'   "top" (top but inside bar), or "above" (above bar outside).
+#'
 #' @param simplify_output
 #'
 #'   `scalar<logical>` // *default:* `TRUE`
@@ -265,17 +272,56 @@
 #'
 #'   Whether to hide label if below this value.
 #'
-#' @param sort_by *What to sort output by*
+#' @param sort_dep_by *What to sort dependent variables by*
+#'
+#'   `vector<character>` // *default:* `".variable_position"` (`optional`)
+#'
+#'   Sort dependent variables in output. When using `indep`-argument,
+#'   sorting differs between ordered factors and unordered factors: Ordering
+#'   of ordered factors is always respected in output (their levels define
+#'   the base order). Unordered factors will be reordered by `sort_dep_by`.
+#'
+#' \describe{
+#' \item{NULL or ".variable_position"}{Sort by variable position in the supplied data frame (default).}
+#' \item{".variable_label"}{Sort by the variable labels.}
+#' \item{".variable_name"}{Sort by the variable names.}
+#' \item{".top"}{The proportion for the highest category available in the variable.}
+#' \item{".upper"}{The sum of the proportions for the categories above the middle category.}
+#' \item{".mid_upper"}{The sum of the proportions for the categories including and above the middle category.}
+#' \item{".mid_lower"}{The sum of the proportions for the categories including and below the middle category.}
+#' \item{".lower"}{The sum of the proportions for the categories below the middle category.}
+#' \item{".bottom"}{The proportions for the lowest category available in the variable.}
+#' }
+#'
+#' @param sort_indep_by *What to sort independent variable categories by*
+#'
+#'   `vector<character>` // *default:* `".factor_order"` (`optional`)
+#'
+#'   Sort independent variable categories in output. When `".factor_order"`,
+#'   preserves the original factor level order for the independent variable.
+#'   Passing `NULL` is accepted and treated as `".factor_order"`.
+#'
+#' \describe{
+#' \item{NULL}{No sorting - preserves original factor level order (default).}
+#' \item{".top"}{The proportion for the highest category available.}
+#' \item{".upper"}{The sum of the proportions for the categories above the middle category.}
+#' \item{".mid_upper"}{The sum of the proportions for the categories including and above the middle category.}
+#' \item{".mid_lower"}{The sum of the proportions for the categories including and below the middle category.}
+#' \item{".lower"}{The sum of the proportions for the categories below the middle category.}
+#' \item{".bottom"}{The proportions for the lowest category available.}
+#' \item{character()}{Character vector of category labels to sum together.}
+#' }
+#'
+#' @param sort_by *What to sort output by (legacy)*
 #'
 #'   `vector<character>` // *default:* `NULL` (`optional`)
 #'
-#'   Sort output (and collapse if requested). When using `indep`-argument,
-#'   sorting differs between ordered factors and unordered factors: Ordering
-#'   of ordered factors is always respected in output. Unordered factors will be
-#'   reordered by `sort_by`. Currently, this works best for a single `dep`.
+#'   **DEPRECATED:** Use `sort_dep_by` and `sort_indep_by` instead for clearer control.
+#'   When specified, this parameter will be used for both dependent and independent sorting.
+#'   If `NULL` (default), dependent variables will be sorted by `.variable_position`.
 #'
 #' \describe{
-#' \item{NULL}{No sorting.}
+#' \item{NULL}{Uses `.variable_position` for dependent variables, no sorting for independent.}
 #' \item{".top"}{The proportion for the highest category available in the variable.}
 #' \item{".upper"}{The sum of the proportions for the categories above the middle category.}
 #' \item{".mid_upper"}{The sum of the proportions for the categories including and above the middle category.}
@@ -293,8 +339,19 @@
 #'
 #'   `scalar<logical>` // *default:* `FALSE` (`optional`)
 #'
-#'   Reverse sorting of `sort_by` in figures and tables. See `arrange_section_by`
-#'   for sorting of report sections.
+#'   Reverse sorting of `sort_by` in figures and tables. Works with both
+#'   ordered and unordered factors - for ordered factors, it reverses the
+#'   display order while preserving the inherent level ordering.
+#'   See `arrange_section_by` for sorting of report sections.
+#'
+#' @param descend_indep *Sorting order for independent variables*
+#'
+#'   `scalar<logical>` // *default:* `FALSE` (`optional`)
+#'
+#'   Reverse sorting of `sort_indep_by` in figures and tables. Works with both
+#'   ordered and unordered factors - for ordered factors, it reverses the
+#'   display order while preserving the inherent level ordering.
+#'   See `arrange_section_by` for sorting of report sections.
 #'
 #' @param table_main_question_as_header *Table main question as header*
 #'
@@ -325,7 +382,7 @@
 #'
 #'   `scalar<integer>` // *default:* `6` (`optional`)
 #'
-#'   ONLY FOR DOCX-OUTPUT. Other output is adjusted using e.g. ggplot2::theme() or set with a global theme (ggplot2::theme_set()).
+#'   ONLY FOR DOCX-OUTPUT. Other output is adjusted using e.g. ggplot2::theme() or set with a global theme (ggplot2::set_theme()).
 #'   Font sizes for general text (6), data label text (3), strip text (6) and legend text (6).
 #'
 #' @param font_family *Font family*
@@ -356,11 +413,7 @@
 #' @examples
 #' makeme(
 #'   data = ex_survey,
-#'   dep = b_1:b_3
-#' )
-#' makeme(
-#'   data = ex_survey,
-#'   dep = b_1, indep = x1_sex
+#'   dep = b_1:b_2
 #' )
 #' makeme(
 #'   data = ex_survey,
@@ -369,114 +422,125 @@
 #' )
 #' makeme(
 #'   data = ex_survey,
-#'   dep = b_1, indep = x1_sex,
-#'   type = "cat_prop_plot_docx"
-#' )
-#' makeme(
-#'   data = ex_survey,
 #'   dep = p_1:p_4, indep = x2_human,
 #'   type = "cat_table_html"
 #' )
 #' makeme(
 #'   data = ex_survey,
-#'   dep = b_1:b_3,
-#'   crowd = c("target", "others", "all"),
+#'   dep = c_1:c_2, indep = x1_sex,
+#'   type = "int_table_html"
+#' )
+#' makeme(
+#'   data = ex_survey,
+#'   dep = b_1:b_2,
+#'   crowd = c("target", "others"),
 #'   mesos_var = "f_uni",
 #'   mesos_group = "Uni of A"
 #' )
 makeme <-
-  function(data,
-           dep = tidyselect::everything(),
-           indep = NULL,
-           type = c(
-             "cat_plot_html",
-             "int_plot_html",
-             "cat_table_html",
-             "int_table_html",
-             "sigtest_table_html",
-             "cat_prop_plot_docx",
-             "cat_freq_plot_docx",
-             "int_plot_docx"
-           ),
-           ...,
-           require_common_categories = TRUE,
-           # Multiple output, splits and selective hiding of variables
-           crowd = c("all"), # "target", "others",
-           mesos_var = NULL,
-           mesos_group = NULL,
-           simplify_output = TRUE,
-           # Hide variable (combinations) for a crowd if...
-           hide_for_crowd_if_all_na = TRUE,
-           hide_for_crowd_if_valid_n_below = 0,
-           hide_for_crowd_if_category_k_below = 2,
-           hide_for_crowd_if_category_n_below = 0,
-           hide_for_crowd_if_cell_n_below = 0,
-           hide_for_all_crowds_if_hidden_for_crowd = NULL,
-           hide_indep_cat_for_all_crowds_if_hidden_for_crowd = FALSE,
-           add_n_to_dep_label = FALSE,
-           add_n_to_indep_label = FALSE,
-           add_n_to_label = FALSE,
-           add_n_to_category = FALSE,
-           totals = FALSE,
-           categories_treated_as_na = NULL,
-           label_separator = " - ",
-           error_on_duplicates = TRUE,
-           showNA = c("ifany", "always", "never"),
-           data_label = c("percentage_bare", "percentage", "proportion", "count"),
-           html_interactive = TRUE,
-           hide_axis_text_if_single_variable = TRUE,
-           hide_label_if_prop_below = .01,
-           inverse = FALSE,
-           vertical = FALSE,
-           digits = 0,
-           data_label_decimal_symbol = ".",
-           x_axis_label_width = 25,
-           strip_width = 25,
-           # Sorting
-           sort_by = ".upper",
-           descend = TRUE,
-           labels_always_at_top = NULL,
-           labels_always_at_bottom = NULL,
-           # For tables
-           table_wide = TRUE,
-           table_main_question_as_header = FALSE,
-           n_categories_limit = 12,
-           translations =
-             list(
-               last_sep = " and ", # Not in use
-               table_heading_N = "Total (N)",
-               table_heading_data_label = "%",
-               add_n_to_dep_label_prefix = " (N = ",
-               add_n_to_dep_label_suffix = ")",
-               add_n_to_indep_label_prefix = " (N = ",
-               add_n_to_indep_label_suffix = ")",
-               add_n_to_label_prefix = " (N = ",
-               add_n_to_label_suffix = ")",
-               add_n_to_category_prefix = " (N = [",
-               add_n_to_category_infix = ",",
-               add_n_to_category_suffix = "])",
-               by_total = "Everyone",
-               sigtest_variable_header_1 = "Var 1",
-               sigtest_variable_header_2 = "Var 2",
-               crowd_all = "All",
-               crowd_target = "Target",
-               crowd_others = "Others"
-             ),
-           # Only for docx, for ggplot2 it is set globally or wtih gplot2::theme()
-           plot_height = 15,
-           colour_palette = NULL,
-           colour_2nd_binary_cat = "#ffffff",
-           colour_na = "grey",
-           label_font_size = 6,
-           main_font_size = 6,
-           strip_font_size = 6,
-           legend_font_size = 6,
-           font_family = "sans",
-           path = NULL,
-           docx_template = NULL) {
+  function(
+    data,
+    dep = tidyselect::everything(),
+    indep = NULL,
+    type = c(
+      "cat_plot_html",
+      "int_plot_html",
+      "cat_table_html",
+      "int_table_html",
+      "sigtest_table_html",
+      "cat_prop_plot_docx",
+      "cat_freq_plot_docx",
+      "int_plot_docx"
+    ),
+    ...,
+    require_common_categories = TRUE,
+    # Multiple output, splits and selective hiding of variables
+    crowd = c("all"), # "target", "others",
+    mesos_var = NULL,
+    mesos_group = NULL,
+    simplify_output = TRUE,
+    # Hide variable (combinations) for a crowd if...
+    hide_for_crowd_if_all_na = TRUE,
+    hide_for_crowd_if_valid_n_below = 0,
+    hide_for_crowd_if_category_k_below = 2,
+    hide_for_crowd_if_category_n_below = 0,
+    hide_for_crowd_if_cell_n_below = 0,
+    hide_for_all_crowds_if_hidden_for_crowd = NULL,
+    hide_indep_cat_for_all_crowds_if_hidden_for_crowd = FALSE,
+    add_n_to_dep_label = FALSE,
+    add_n_to_indep_label = FALSE,
+    add_n_to_label = FALSE,
+    add_n_to_category = FALSE,
+    totals = FALSE,
+    categories_treated_as_na = NULL,
+    label_separator = " - ",
+    error_on_duplicates = TRUE,
+    showNA = c("ifany", "always", "never"),
+    data_label = c(
+      "percentage_bare",
+      "percentage",
+      "proportion",
+      "count",
+      "mean",
+      "median"
+    ),
+    data_label_position = c("center", "bottom", "top", "above"),
+    html_interactive = TRUE,
+    hide_axis_text_if_single_variable = TRUE,
+    hide_label_if_prop_below = .01,
+    inverse = FALSE,
+    vertical = FALSE,
+    digits = 0,
+    data_label_decimal_symbol = ".",
+    x_axis_label_width = 25,
+    strip_width = 25,
+    # Sorting
+    sort_dep_by = ".variable_position",
+    sort_indep_by = ".factor_order",
+    sort_by = NULL,
+    descend = TRUE,
+    descend_indep = FALSE,
+    labels_always_at_top = NULL,
+    labels_always_at_bottom = NULL,
+    # For tables
+    table_wide = TRUE,
+    table_main_question_as_header = FALSE,
+    n_categories_limit = 12,
+    translations = list(
+      last_sep = " and ", # Not in use
+      table_heading_N = "Total (N)",
+      table_heading_data_label = "%",
+      add_n_to_dep_label_prefix = " (N = ",
+      add_n_to_dep_label_suffix = ")",
+      add_n_to_indep_label_prefix = " (N = ",
+      add_n_to_indep_label_suffix = ")",
+      add_n_to_label_prefix = " (N = ",
+      add_n_to_label_suffix = ")",
+      add_n_to_category_prefix = " (N = [",
+      add_n_to_category_infix = ",",
+      add_n_to_category_suffix = "])",
+      by_total = "Everyone",
+      sigtest_variable_header_1 = "Var 1",
+      sigtest_variable_header_2 = "Var 2",
+      crowd_all = "All",
+      crowd_target = "Target",
+      crowd_others = "Others"
+    ),
+    # Only for docx, for ggplot2 it is set globally or wtih gplot2::theme()
+    plot_height = 15,
+    colour_palette = NULL,
+    colour_2nd_binary_cat = "#ffffff",
+    colour_na = "grey",
+    label_font_size = 6,
+    main_font_size = 6,
+    strip_font_size = 6,
+    legend_font_size = 6,
+    font_family = "sans",
+    path = NULL,
+    docx_template = NULL
+  ) {
     ##
 
-
     dep_enq <- rlang::enquo(arg = dep)
     dep_pos <- tidyselect::eval_select(dep_enq, data = data)
     indep_enq <- rlang::enquo(arg = indep)
@@ -489,229 +553,64 @@ makeme <-
       default_values = formals(makeme)
     )
 
-    args$data <- data # reinsert after check_options
-    args$dep <- names(dep_pos)
-    args$indep <- names(indep_pos)
-    args$showNA <- args$showNA[1]
-    args$data_label <- args$data_label[1]
-    args$type <- eval(args$type)[1]
-
-    validate_makeme_options(params = args)
-
-
-    if (!args$type %in% c("sigtest_table_html")) {
-      check_multiple_indep(data, indep = {{ indep }})
-      check_category_pairs(data = data, cols_pos = c(dep_pos))
+    # Handle sort_by parameter logic
+    if (!is.null(args$sort_by)) {
+      # If sort_by is specified and the new parameters are defaults, use sort_by for both
+      if (
+        identical(args$sort_dep_by, ".variable_position") &&
+          (is.null(args$sort_indep_by) ||
+            identical(args$sort_indep_by, ".factor_order"))
+      ) {
+        args$sort_dep_by <- args$sort_by
+        args$sort_indep_by <- args$sort_by
+      }
+      # Issue deprecation warning
+      cli::cli_warn(
+        "The 'sort_by' parameter is deprecated. Use 'sort_dep_by' and 'sort_indep_by' instead for clearer control.",
+        call. = FALSE
+      )
     }
 
+    # Convert NULL to .variable_position for sort_dep_by
+    if (is.null(args$sort_dep_by)) {
+      args$sort_dep_by <- ".variable_position"
+    }
 
+    # Convert NULL to .factor_order for sort_indep_by (explicitly allowed)
+    if (is.null(args$sort_indep_by)) {
+      args$sort_indep_by <- ".factor_order"
+    }
 
-
-    # if(grepl(x=args$type, pattern = "freq")) args$data_label <- "count"
-
-    # Set hide_for_all_crowds_if_hidden_for_crowd first to get its excluded variables early
-    # This only happens if hide_for_all_crowds_if_hidden_for_crowd are in the set of crowd.
-    args$crowd <- c(
-      args$hide_for_all_crowds_if_hidden_for_crowd[args$hide_for_all_crowds_if_hidden_for_crowd %in% args$crowd],
-      args$crowd[!args$crowd %in% args$hide_for_all_crowds_if_hidden_for_crowd[args$hide_for_all_crowds_if_hidden_for_crowd %in% args$crowd]]
+    # Setup and validate arguments
+    args <- setup_and_validate_makeme_args(
+      args,
+      data,
+      dep_pos,
+      indep_pos,
+      {{ indep }}
     )
 
+    # Initialize crowd-based filtering
+    crowd_filtering <- initialize_crowd_filtering(args$crowd, args)
+    kept_cols_list <- crowd_filtering$kept_cols_list
+    omitted_cols_list <- crowd_filtering$omitted_cols_list
+    kept_indep_cats_list <- crowd_filtering$kept_indep_cats_list
 
-    kept_cols_list <- rlang::set_names(vector(mode = "list", length = length(args$crowd)), args$crowd)
-    omitted_cols_list <- rlang::set_names(vector(mode = "list", length = length(args$crowd)), args$crowd)
-    kept_indep_cats_list <- rlang::set_names(vector(mode = "list", length = length(args$crowd)), args$crowd)
+    # Process global independent category hiding logic
+    kept_indep_cats_list <- process_global_indep_categories(
+      kept_indep_cats_list,
+      args$hide_for_all_crowds_if_hidden_for_crowd
+    )
 
-    for (crwd in names(kept_cols_list)) {
-      kept_cols_tmp <-
-        keep_cols(
-          data = args$data,
-          dep = args$dep,
-          indep = args$indep,
-          crowd = crwd,
-          mesos_var = args$mesos_var,
-          mesos_group = args$mesos_group,
-          hide_for_crowd_if_all_na = args$hide_for_crowd_if_all_na, # 1
-          hide_for_crowd_if_valid_n_below = args$hide_for_crowd_if_valid_n_below, # 2
-          hide_for_crowd_if_category_k_below = args$hide_for_crowd_if_category_k_below, # 3
-          hide_for_crowd_if_category_n_below = args$hide_for_crowd_if_category_n_below, # 4
-          hide_for_crowd_if_cell_n_below = args$hide_for_crowd_if_cell_n_below # , # 5
-          # hide_for_all_crowds_if_hidden_for_crowd_vars = omitted_vars
-        )
-      omitted_cols_list[[crwd]] <- kept_cols_tmp[["omitted_vars"]]
-
-      kept_indep_cats_list[[crwd]] <-
-        keep_indep_cats(
-          data = kept_cols_tmp[["data"]],
-          indep = args$indep
-        )
-    }
-
-
-
-    kept_indep_cats_list <-
-      lapply(rlang::set_names(names(kept_indep_cats_list)), function(crwd) {
-        lapply(rlang::set_names(names(kept_indep_cats_list[[crwd]])), function(x) {
-          if (is.character(args$hide_for_all_crowds_if_hidden_for_crowd) &&
-            !crwd %in% args$hide_for_all_crowds_if_hidden_for_crowd) {
-            kept_globally <-
-              kept_indep_cats_list[args$hide_for_all_crowds_if_hidden_for_crowd] |>
-              unlist() |>
-              unique()
-
-            kept_indep_cats_list[[crwd]][[x]][
-              kept_indep_cats_list[[crwd]][[x]] %in%
-                kept_globally
-            ]
-          } else {
-            kept_indep_cats_list[[crwd]][[x]]
-          }
-        })
-      })
-
-    out <- rlang::set_names(vector(mode = "list", length = length(args$crowd)), args$crowd)
-
-
-
-
-    for (crwd in names(out)) {
-      #
-      omitted_vars_crwd <-
-        omitted_cols_list[
-          c(
-            crwd,
-            args$hide_for_all_crowds_if_hidden_for_crowd
-          )
-        ] |>
-        lapply(FUN = function(x) if ("omitted_vars" %in% names(x)) x["omitted_vars"]) |>
-        unlist() |>
-        unique()
-
-
-      dep_crwd <- args$dep[!args$dep %in% omitted_vars_crwd]
-      if (length(dep_crwd) == 0) next
-
-      indep_crwd <- args$indep
-      if (length(indep_crwd) == 0) indep_crwd <- NULL
-
-
-
-      subset_data <-
-        dplyr::filter(
-          args$data[, # subetting would remove variable labels, filter keeps them
-            !colnames(args$data) %in% omitted_vars_crwd,
-            drop = FALSE
-          ],
-          makeme_keep_rows(
-            data = data,
-            crwd = crwd,
-            mesos_var = mesos_var,
-            mesos_group = mesos_group
-          )
-        )
-
-      if (isTRUE(args$hide_indep_cat_for_all_crowds_if_hidden_for_crowd)) {
-        for (x in indep_crwd) {
-          subset_data <-
-            dplyr::filter(subset_data, as.character(subset_data[[x]]) %in%
-              kept_indep_cats_list[[crwd]][[x]])
-        }
-      }
-
-      if (nrow(subset_data) == 0) {
-        indep_msg <- if (is.character(args$indep)) paste0("indep=", cli::ansi_collapse(args$indep))
-        cli::cli_warn(c("No data left to make you {.arg {args$type}} with dep={.arg {args$dep}}, {.arg {indep_msg}}, crowd={.arg {crwd}}.",
-          i = "Skipping."
-        ))
-        next
-      }
-
-      variable_type_dep <-
-        lapply(args$dep, function(v) class(subset_data[[v]])) |>
-        unlist()
-
-      # Future: switch or S3
-      if (all(variable_type_dep %in% c("integer", "numeric")) &&
-        (all(indep_crwd) %in% c("factor", "ordered", "character") ||
-          length(indep_crwd) == 0)) {
-        args$data_summary <-
-          summarize_int_cat_data(
-            data = subset_data,
-            dep = dep_crwd,
-            indep = indep_crwd,
-            ...
-          )
-      } else if (all(variable_type_dep %in% c("factor", "ordered", "character"))) {
-        args$data_summary <-
-          summarize_cat_cat_data(
-            data = subset_data,
-            dep = dep_crwd,
-            indep = indep_crwd,
-            ...,
-            label_separator = args$label_separator,
-            showNA = args$showNA,
-            totals = args$totals,
-            sort_by = args$sort_by,
-            descend = args$descend,
-            data_label = args$data_label,
-            digits = args$digits,
-            add_n_to_dep_label = args$add_n_to_dep_label,
-            add_n_to_indep_label = args$add_n_to_indep_label,
-            add_n_to_label = args$add_n_to_label,
-            add_n_to_category = args$add_n_to_category,
-            hide_label_if_prop_below = args$hide_label_if_prop_below,
-            data_label_decimal_symbol = args$data_label_decimal_symbol,
-            categories_treated_as_na = args$categories_treated_as_na,
-            labels_always_at_bottom = args$labels_always_at_bottom,
-            labels_always_at_top = args$labels_always_at_top,
-            translations = args$translations
-          )
-      } else {
-        cli::cli_abort(c(
-          "You have provided a mix of categorical and continuous variables.",
-          "I do not know what to do with that!"
-        ))
-      }
-
-      args$main_question <-
-        as.character(unique(args$data_summary[[".variable_label_prefix"]]))
-
-      check_no_duplicated_label_suffix(data_summary = args$data_summary, error_on_duplicates = args$error_on_duplicates)
-
-      if (!args$type %in% c("sigtest_table_html")) {
-        args$data_summary <-
-          post_process_makeme_data(
-            data = args$data_summary,
-            indep = indep_crwd,
-            showNA = args$showNA,
-            colour_2nd_binary_cat = if (grepl(x = args$type, pattern = "docx")) args$colour_2nd_binary_cat
-          )
-      }
-
-      args_crwd <- args
-      args_crwd$dep <- dep_crwd
-      args_crwd$indep <- indep_crwd
-
-      out[[crwd]] <-
-        suppressPackageStartupMessages(
-          rlang::exec(make_content,
-            type = args_crwd$type,
-            !!!args_crwd[!names(args_crwd) %in% c("type")]
-          )
-        )
-    }
-
-    for (crwd in names(out)) {
-      if (rlang::is_string(args$translations[[paste0("crowd_", crwd)]])) {
-        names(out)[names(out) == crwd] <- args$translations[[paste0("crowd_", crwd)]]
-      }
-    }
-    out <- out[lapply(out, function(x) !is.null(x)) |> unlist()]
-
-    if (isTRUE(args$simplify_output) && length(out) == 1) {
-      out[[1]]
-    } else if (length(out) == 0) {
-      NULL
-    } else {
-      out
-    }
+    # Process all crowds and generate final output
+    out <- process_all_crowds(
+      args,
+      omitted_cols_list,
+      kept_indep_cats_list,
+      data,
+      mesos_var,
+      mesos_group,
+      ...
+    )
+    process_output_results(out, args)
   }
